Class: Serega::SeregaPlugins::Batch::BatchConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/serega/plugins/batch/lib/batch_config.rb

Overview

Batch plugin config

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(opts) ⇒ BatchConfig

Returns a new instance of BatchConfig.



12
13
14
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 12

def initialize(opts)
  @opts = opts
end

Instance Attribute Details

#optsObject (readonly)

Returns the value of attribute opts.



10
11
12
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 10

def opts
  @opts
end

Instance Method Details

#auto_hideBoolean?

Shows option to auto hide attributes with :batch specified

Returns:

  • (Boolean, nil)

    option value



49
50
51
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 49

def auto_hide
  opts[:auto_hide]
end

#auto_hide=(value) ⇒ Boolean

Returns New option value.

Parameters:

  • value (Boolean)

    New :auto_hide option value

Returns:

  • (Boolean)

    New option value

Raises:



55
56
57
58
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 55

def auto_hide=(value)
  raise SeregaError, "Must have boolean value, #{value.inspect} provided" if (value != true) && (value != false)
  opts[:auto_hide] = value
end

#define(loader_name, callable = nil, &block) ⇒ void

This method returns an undefined value.

Defines batch loader

Parameters:

  • loader_name (Symbol)

    Batch loader name, that is used when defining attribute with batch loader.

  • block (Proc)

    Block that can accept 3 parameters - ids, context, plan_point and returns hash with ids as keys and values are batch loaded objects



25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 25

def define(loader_name, callable = nil, &block)
  if (!callable && !block) || (callable && block)
    raise SeregaError, "Batch loader can be specified with one of arguments - callable value or &block"
  end

  callable ||= block
  SeregaValidations::Utils::CheckExtraKeywordArg.call(callable, "batch loader `#{loader_name}`")
  params_count = SeregaUtils::ParamsCount.call(callable, max_count: 3)

  if params_count > 3
    raise SeregaError, "Batch loader can have maximum 3 parameters (ids, context, plan)"
  end

  loaders[loader_name] = callable
end

#id_methodSymbol, ...

Shows method name or callable object needed to get object identifier for batch load

Returns:

  • (Symbol, #call, nil)

    Default method name or callable object to get identifier



62
63
64
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 62

def id_method
  opts[:id_method]
end

#id_method=(value) ⇒ Boolean

Sets new identifier method name or callable value needed for batch loading

Parameters:

  • value (Symbol, #call)

    New :id_method value

Returns:

  • (Boolean)

    New option value



70
71
72
73
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 70

def id_method=(value)
  CheckBatchOptIdMethod.call(value)
  opts[:id_method] = value
end

#loadersHash

Shows defined loaders

Returns:

  • (Hash)

    defined loaders



43
44
45
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 43

def loaders
  opts[:loaders]
end