Module: Serega::SeregaPlugins::Batch::MapPointInstanceMethods

Defined in:
lib/serega/plugins/batch/batch.rb

Overview

Serega::SeregaMapPoint additional/patched class methods

Instance Method Summary collapse

Instance Method Details

#batchBatchOptionModel

Returns BatchOptionModel, an object that combines options and methods needed to load batch

Returns:

  • (BatchOptionModel)

    Class that combines options and methods needed to load batch.



226
227
228
229
230
231
232
233
# File 'lib/serega/plugins/batch/batch.rb', line 226

def batch
  return @batch if instance_variable_defined?(:@batch)

  @batch = begin
    opts = attribute.batch
    BatchOptionModel.new(attribute) if opts
  end
end