Module: Serega::SeregaPlugins::Formatters::AttributeNormalizerInstanceMethods
- Defined in:
- lib/serega/plugins/formatters/formatters.rb
Overview
AttributeNormalizer class additional/patched instance methods
Instance Method Summary collapse
-
#formatter ⇒ Proc, ...
Block or callable instance that will format attribute values.
-
#formatter_signature ⇒ String?
Returns formatter method signature for optimized calling.
Instance Method Details
#formatter ⇒ Proc, ...
Block or callable instance that will format attribute values
167 168 169 |
# File 'lib/serega/plugins/formatters/formatters.rb', line 167 def formatter @formatter ||= prepare_formatter end |
#formatter_signature ⇒ String?
Returns formatter method signature for optimized calling
176 177 178 |
# File 'lib/serega/plugins/formatters/formatters.rb', line 176 def formatter_signature @formatter_signature ||= prepare_formatter_signature end |