Module: Serega::SeregaPlugins::If::PlanPointInstanceMethods

Defined in:
lib/serega/plugins/if/if.rb

Overview

Serega::SeregaPlanPoint additional/patched instance methods

Instance Method Summary collapse

Instance Method Details

#satisfy_if_conditions?(obj, ctx) ⇒ Boolean

Returns Should we show attribute or not Conditions for this checks are specified by :if and :unless attribute options.

Returns:

  • (Boolean)

    Should we show attribute or not Conditions for this checks are specified by :if and :unless attribute options.



188
189
190
# File 'lib/serega/plugins/if/if.rb', line 188

def satisfy_if_conditions?(obj, ctx)
  check_if_unless(obj, ctx, :if, :unless)
end

#satisfy_if_value_conditions?(value, ctx) ⇒ Boolean

Returns Should we show attribute with specific value or not. Conditions for this checks are specified by :if_value and :unless_value attribute options.

Returns:

  • (Boolean)

    Should we show attribute with specific value or not. Conditions for this checks are specified by :if_value and :unless_value attribute options.



196
197
198
# File 'lib/serega/plugins/if/if.rb', line 196

def satisfy_if_value_conditions?(value, ctx)
  check_if_unless(value, ctx, :if_value, :unless_value)
end