Module: Serega::SeregaPlugins::Presenter::SeregaObjectSerializerInstanceMethods

Defined in:
lib/serega/plugins/presenter/presenter.rb

Overview

SeregaObjectSerializer additional/patched class methods

Instance Method Summary collapse

Instance Method Details

#initialize(**opts) ⇒ Object

The custom-presenter check is made once per object serializer here and its result is reused for every enqueued chunk of the level.



216
217
218
219
# File 'lib/serega/plugins/presenter/presenter.rb', line 216

def initialize(**opts)
  super
  @wrap_in_presenter = self.class.serializer_class.custom_presenter?
end