Class: Serega::Validations::Attribute::CheckBlock
- Inherits:
-
Object
- Object
- Serega::Validations::Attribute::CheckBlock
- Defined in:
- lib/serega/validations/attribute/check_block.rb
Class Method Summary collapse
-
.call(block) ⇒ void
Checks :value option or a block provided with attribute Must have up to two arguments - object and context.
Class Method Details
.call(block) ⇒ void
This method returns an undefined value.
Checks :value option or a block provided with attribute Must have up to two arguments - object and context. It should not have any *rest or **key arguments
29 30 31 32 33 |
# File 'lib/serega/validations/attribute/check_block.rb', line 29 def call(block) return unless block check_block(block) end |