Module: Serega::ClassMethods
- Included in:
- Serega
- Defined in:
- lib/serega.rb
Overview
Serializers class methods
Instance Attribute Summary collapse
-
#config ⇒ SeregaConfig
readonly
Returns current config.
Instance Method Summary collapse
-
#as_json(object, opts = nil) ⇒ Hash
Serializes provided object as JSON.
-
#attribute(name, **opts, &block) ⇒ Serega::SeregaAttribute
Adds attribute.
-
#attributes ⇒ Hash
Lists attributes.
-
#call(object, opts = nil) ⇒ Hash
Serializes provided object to Hash.
-
#plugin(name, **opts) ⇒ class<Module>
Enables plugin for current serializer.
-
#plugin_used?(name) ⇒ Boolean
Checks plugin is used.
- #to_h(object, opts = nil) ⇒ Object
-
#to_json(object, opts = nil) ⇒ String
Serializes provided object to JSON string.
Instance Attribute Details
#config ⇒ SeregaConfig (readonly)
Returns current config
74 75 76 |
# File 'lib/serega.rb', line 74 def config @config end |
Instance Method Details
#as_json(object, opts = nil) ⇒ Hash
Serializes provided object as JSON
212 213 214 |
# File 'lib/serega.rb', line 212 def as_json(object, opts = nil) config.from_json.call(to_json(object, opts)) end |
#attribute(name, **opts, &block) ⇒ Serega::SeregaAttribute
Adds attribute
Patched in:
-
plugin :presenter (additionally adds method in Presenter class)
141 142 143 144 |
# File 'lib/serega.rb', line 141 def attribute(name, **opts, &block) attribute = self::SeregaAttribute.new(name: name, opts: opts, block: block) attributes[attribute.name] = attribute end |
#attributes ⇒ Hash
Lists attributes
125 126 127 |
# File 'lib/serega.rb', line 125 def attributes @attributes ||= {} end |
#call(object, opts = nil) ⇒ Hash
Serializes provided object to Hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/serega.rb', line 160 def call(object, opts = nil) opts ||= FROZEN_EMPTY_HASH initiate_keys = config.initiate_keys if opts.empty? modifiers_opts = FROZEN_EMPTY_HASH serialize_opts = nil else serialize_opts = opts.except(*initiate_keys) modifiers_opts = opts.slice(*initiate_keys) end new(modifiers_opts).to_h(object, serialize_opts) end |
#plugin(name, **opts) ⇒ class<Module>
Enables plugin for current serializer
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/serega.rb', line 83 def plugin(name, **opts) raise SeregaError, "This plugin is already loaded" if plugin_used?(name) plugin = SeregaPlugins.find_plugin(name) # We split loading of plugin to three parts - before_load, load, after_load: # # - **before_load_plugin** usually used to check requirements and to load additional plugins # - **load_plugin** usually used to include plugin modules # - **after_load_plugin** usually used to add config options plugin.before_load_plugin(self, **opts) if plugin.respond_to?(:before_load_plugin) plugin.load_plugin(self, **opts) if plugin.respond_to?(:load_plugin) plugin.after_load_plugin(self, **opts) if plugin.respond_to?(:after_load_plugin) # Store attached plugins, so we can check it is loaded later config.plugins << (plugin.respond_to?(:plugin_name) ? plugin.plugin_name : plugin) plugin end |
#plugin_used?(name) ⇒ Boolean
Checks plugin is used
110 111 112 113 114 115 116 117 118 |
# File 'lib/serega.rb', line 110 def plugin_used?(name) plugin_name = case name when Module then name.respond_to?(:plugin_name) ? name.plugin_name : name else name end config.plugins.include?(plugin_name) end |
#to_h(object, opts = nil) ⇒ Object
176 177 178 |
# File 'lib/serega.rb', line 176 def to_h(object, opts = nil) call(object, opts) end |
#to_json(object, opts = nil) ⇒ String
Serializes provided object to JSON string
194 195 196 |
# File 'lib/serega.rb', line 194 def to_json(object, opts = nil) config.to_json.call(to_h(object, opts)) end |