Module: Serega::ClassMethods
- Included in:
- Serega
- Defined in:
- lib/serega.rb
Overview
Core serializer class methods
Instance Attribute Summary collapse
-
#config ⇒ SeregaConfig
readonly
Current serializer config.
Instance Method Summary collapse
- #as_json(object, opts = FROZEN_EMPTY_HASH) ⇒ Object
-
#attribute(name, **opts, &block) ⇒ Serega::SeregaAttribute
Adds attribute.
-
#attributes ⇒ Hash
Lists attributes.
- #call(object, opts = FROZEN_EMPTY_HASH) ⇒ Object
-
#plugin(name, **opts) ⇒ class<Module>
Enables plugin for current serializer.
-
#plugin_used?(name) ⇒ Boolean
Checks plugin is used.
- #to_h(object, opts = FROZEN_EMPTY_HASH) ⇒ Object
- #to_json(object, opts = FROZEN_EMPTY_HASH) ⇒ Object
Instance Attribute Details
#config ⇒ SeregaConfig (readonly)
Returns current serializer config.
74 75 76 |
# File 'lib/serega.rb', line 74 def config @config end |
Instance Method Details
#as_json(object, opts = FROZEN_EMPTY_HASH) ⇒ Object
200 201 202 203 |
# File 'lib/serega.rb', line 200 def as_json(object, opts = FROZEN_EMPTY_HASH) initiate_keys = config[:initiate_keys] new(opts.slice(*initiate_keys)).as_json(object, opts.except(*initiate_keys)) end |
#attribute(name, **opts, &block) ⇒ Serega::SeregaAttribute
Adds attribute
181 182 183 184 |
# File 'lib/serega.rb', line 181 def attribute(name, **opts, &block) attribute = self::SeregaAttribute.new(name: name, opts: opts, block: block) attributes[attribute.name] = attribute end |
#attributes ⇒ Hash
Lists attributes
168 169 170 |
# File 'lib/serega.rb', line 168 def attributes @attributes ||= {} end |
#call(object, opts = FROZEN_EMPTY_HASH) ⇒ Object
186 187 188 189 |
# File 'lib/serega.rb', line 186 def call(object, opts = FROZEN_EMPTY_HASH) initiate_keys = config[:initiate_keys] new(opts.slice(*initiate_keys)).to_h(object, opts.except(*initiate_keys)) end |
#plugin(name, **opts) ⇒ class<Module>
Enables plugin for current serializer
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/serega.rb', line 126 def plugin(name, **opts) raise SeregaError, "This plugin is already loaded" if plugin_used?(name) plugin = SeregaPlugins.find_plugin(name) # We split loading of plugin to three parts - before_load, load, after_load: # # - **before_load_plugin** usually used to check requirements and to load additional plugins # - **load_plugin** usually used to include plugin modules # - **after_load_plugin** usually used to add config options plugin.before_load_plugin(self, **opts) if plugin.respond_to?(:before_load_plugin) plugin.load_plugin(self, **opts) if plugin.respond_to?(:load_plugin) plugin.after_load_plugin(self, **opts) if plugin.respond_to?(:after_load_plugin) # Store attached plugins, so we can check it is loaded later config[:plugins] << (plugin.respond_to?(:plugin_name) ? plugin.plugin_name : plugin) plugin end |
#plugin_used?(name) ⇒ Boolean
Checks plugin is used
153 154 155 156 157 158 159 160 161 |
# File 'lib/serega.rb', line 153 def plugin_used?(name) plugin_name = case name when Module then name.respond_to?(:plugin_name) ? name.plugin_name : name else name end config[:plugins].include?(plugin_name) end |
#to_h(object, opts = FROZEN_EMPTY_HASH) ⇒ Object
191 192 193 |
# File 'lib/serega.rb', line 191 def to_h(object, opts = FROZEN_EMPTY_HASH) call(object, opts) end |
#to_json(object, opts = FROZEN_EMPTY_HASH) ⇒ Object
195 196 197 198 |
# File 'lib/serega.rb', line 195 def to_json(object, opts = FROZEN_EMPTY_HASH) initiate_keys = config[:initiate_keys] new(opts.slice(*initiate_keys)).to_json(object, opts.except(*initiate_keys)) end |