Class: Serega::SeregaPlugins::Batch::BatchConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/serega/plugins/batch/lib/batch_config.rb

Overview

Batch plugin config

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(opts) ⇒ BatchConfig

Returns a new instance of BatchConfig.



12
13
14
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 12

def initialize(opts)
  @opts = opts
end

Instance Attribute Details

#optsObject (readonly)

Returns the value of attribute opts.



10
11
12
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 10

def opts
  @opts
end

Instance Method Details

#auto_hideBoolean?

Shows option to auto hide attributes with :batch specified

Returns:

  • (Boolean, nil)

    option value



56
57
58
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 56

def auto_hide
  opts[:auto_hide]
end

#auto_hide=(value) ⇒ Boolean

Returns New option value.

Parameters:

  • value (Boolean)

    New :auto_hide option value

Returns:

  • (Boolean)

    New option value

Raises:



62
63
64
65
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 62

def auto_hide=(value)
  raise SeregaError, "Must have boolean value, #{value.inspect} provided" if (value != true) && (value != false)
  opts[:auto_hide] = value
end

#default_keySymbol?

Shows default key for :batch option

Returns:

  • (Symbol, nil)

    default key for :batch option



69
70
71
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 69

def default_key
  opts[:default_key]
end

#default_key=(value) ⇒ Boolean

Returns New option value.

Parameters:

  • value (Symbol)

    New :default_key option value

Returns:

  • (Boolean)

    New option value

Raises:



75
76
77
78
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 75

def default_key=(value)
  raise SeregaError, "Must be a Symbol, #{value.inspect} provided" unless value.is_a?(Symbol)
  opts[:default_key] = value
end

#define(loader_name, &block) ⇒ void

This method returns an undefined value.

Defines batch loader

Parameters:

  • loader_name (Symbol)

    Batch loader name, that is used when defining attribute with batch loader.

  • block (Proc)

    Block that can accept 3 parameters - keys, context, plan_point and returns hash where ids are keys and values are batch loaded objects/



25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 25

def define(loader_name, &block)
  unless block
    raise SeregaError, "Block must be given to #define method"
  end

  params = block.parameters
  if params.count > 3 || !params.all? { |param| (param[0] == :req) || (param[0] == :opt) }
    raise SeregaError, "Block can have maximum 3 regular parameters"
  end

  loaders[loader_name] = block
end

#fetch_loader(loader_name) ⇒ Proc

Finds previously defined batch loader by name

Parameters:

  • loader_name (Symbol)

Returns:

  • (Proc)

    batch loader block



50
51
52
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 50

def fetch_loader(loader_name)
  loaders[loader_name] || (raise SeregaError, "Batch loader with name `#{loader_name.inspect}` was not defined. Define example: config.batch.define(:#{loader_name}) { |keys, ctx, points| ... }")
end

#loadersHash

Shows defined loaders

Returns:

  • (Hash)

    defined loaders



40
41
42
# File 'lib/serega/plugins/batch/lib/batch_config.rb', line 40

def loaders
  opts[:loaders]
end