Class: Serega::SeregaPlugins::Batch::BatchConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/serega/plugins/batch/batch.rb

Overview

Batch loader config

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(opts) ⇒ BatchConfig

Returns a new instance of BatchConfig.



144
145
146
# File 'lib/serega/plugins/batch/batch.rb', line 144

def initialize(opts)
  @opts = opts
end

Instance Attribute Details

#optsObject (readonly)

Returns the value of attribute opts.



142
143
144
# File 'lib/serega/plugins/batch/batch.rb', line 142

def opts
  @opts
end

Instance Method Details

#auto_hideBoolean?

Shows option to auto hide attributes with :batch specified

Returns:

  • (Boolean, nil)

    option value



188
189
190
# File 'lib/serega/plugins/batch/batch.rb', line 188

def auto_hide
  opts[:auto_hide]
end

#auto_hide=(value) ⇒ Boolean

Returns New option value.

Parameters:

  • value (Boolean)

    New :auto_hide option value

Returns:

  • (Boolean)

    New option value

Raises:



194
195
196
197
# File 'lib/serega/plugins/batch/batch.rb', line 194

def auto_hide=(value)
  raise SeregaError, "Must have boolean value, #{value.inspect} provided" if (value != true) && (value != false)
  opts[:auto_hide] = value
end

#default_keySymbol?

Shows default key for :batch option

Returns:

  • (Symbol, nil)

    default key for :batch option



201
202
203
# File 'lib/serega/plugins/batch/batch.rb', line 201

def default_key
  opts[:default_key]
end

#default_key=(value) ⇒ Boolean

Returns New option value.

Parameters:

  • value (Symbol)

    New :default_key option value

Returns:

  • (Boolean)

    New option value

Raises:



207
208
209
210
# File 'lib/serega/plugins/batch/batch.rb', line 207

def default_key=(value)
  raise SeregaError, "Must be a Symbol, #{value.inspect} provided" unless value.is_a?(Symbol)
  opts[:default_key] = value
end

#define(loader_name, &block) ⇒ void

This method returns an undefined value.

Defines batch loader

Parameters:

  • loader_name (Symbol)

    Batch loader name, that is used when defining attribute with batch loader.

  • block (Proc)

    Block that can accept 3 parameters - keys, context, plan_point and returns hash where ids are keys and values are batch loaded objects/



157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/serega/plugins/batch/batch.rb', line 157

def define(loader_name, &block)
  unless block
    raise SeregaError, "Block must be given to #define method"
  end

  params = block.parameters
  if params.count > 3 || !params.all? { |param| (param[0] == :req) || (param[0] == :opt) }
    raise SeregaError, "Block can have maximum 3 regular parameters"
  end

  loaders[loader_name] = block
end

#fetch_loader(loader_name) ⇒ Proc

Finds previously defined batch loader by name

Parameters:

  • loader_name (Symbol)

Returns:

  • (Proc)

    batch loader block



182
183
184
# File 'lib/serega/plugins/batch/batch.rb', line 182

def fetch_loader(loader_name)
  loaders[loader_name] || (raise SeregaError, "Batch loader with name `#{loader_name.inspect}` was not defined. Define example: config.batch.define(:#{loader_name}) { |keys, ctx, points| ... }")
end

#loadersHash

Shows defined loaders

Returns:

  • (Hash)

    defined loaders



172
173
174
# File 'lib/serega/plugins/batch/batch.rb', line 172

def loaders
  opts[:loaders]
end