Module: Serega::SeregaPlugins::Formatters::AttributeNormalizerInstanceMethods
- Defined in:
- lib/serega/plugins/formatters/formatters.rb
Overview
Attribute class additional/patched instance methods
Instance Method Summary collapse
-
#formatter ⇒ Proc, ...
Block or callable instance that will format attribute values.
Instance Method Details
#formatter ⇒ Proc, ...
Block or callable instance that will format attribute values
156 157 158 159 160 |
# File 'lib/serega/plugins/formatters/formatters.rb', line 156 def formatter return @formatter if instance_variable_defined?(:@formatter) @formatter = prepare_formatter end |